@@ -1,7 +1,6 @@
 
 # dropNulls
-dropNulls <- function (x)
-{
+dropNulls <- function(x) {
   x[!vapply(x, is.null, FUN.VALUE = logical(1))]
 }
 
